<?php
// $Id: Shell.php.create.User
// Copyright (c) 2008-2023 Michael Stauber, SOLARSPEED.NET
// Copyright (c) 2008-2023 Team BlueOnyx, BLUEONYX.IT
// Copyright (c) 2001 Sun Microsystems, Inc.
// All Rights Reserved.

include_once('UIExtension.php');

class ShellExtension extends UIExtension {
    function display(&$ServerScriptHelper, &$container, $parameters) {
        $factory = $ServerScriptHelper->getHtmlComponentFactory("base-shell");
        $cce = $ServerScriptHelper->getCceClient();

        $CI = get_instance();
        $System = $CI->getSystem();
        $i18n = new I18n("base-shell", $CI->BX_SESSION['loginUser']['localePreference']);

        $System_SSH = $cce->get($System['OID'], 'SSH');

        // if configuring for virtual sites, don't show if the feature
        // is not enabled 
        if ( isset($parameters["VSITE_OID"]) ) {
            $feature = $cce->get($parameters["VSITE_OID"], "Shell");
            if ( !$feature["enabled"] ) {
                return; 
            }
        }
        $defaults = $cce->get($parameters["CCE_SERVICES_OID"], "Shell");
        $defaultsSSH['GoogleAuthentication'] = $System_SSH['GoogleAuthentication'];

        // Sense checks:
        if (($System_SSH['GoogleAuthentication'] == '0') && ($defaults['GoogleAuthentication'] == '1')) {
            // System has 'GoogleAuthentication' OFF, so Users of this Vsite cannot have it ON:
            $defaults['GoogleAuthentication'] = '0';
        }

        if (isset($feature['GoogleAuthentication'])) {
            if (($feature['GoogleAuthentication'] == '0') && ($defaults['GoogleAuthentication'] == '1')) {
                // Vsite has 'GoogleAuthentication' OFF, so Users of this Vsite cannot have it ON:
                $defaults['GoogleAuthentication'] = '0';
            }
        }

        //
        //-- Page:
        //
    
        $shellEnable = $factory->getBoolean("Shell_enabled", $defaults["enabled"]);
        
        // assume PagedBlock because that is most likely going to be it
        $pageIds = $container->getPageIds();
        $container->addFormField(
                $shellEnable, 
                $factory->getLabel("userEnableShell"), $pageIds[0]);

        // Google Authenticator enabled or not:
        $GA_access = 'rw';
        if (($System_SSH['GoogleAuthentication'] == '0') || ($feature['GoogleAuthentication'] == '0')) {
            // 'GoogleAuthentication' is disabled in the server settings or Vsite settings:
            $defaults['GoogleAuthentication'] = '0';
            $GA_access = 'r';
        }
        $GoogleAuthentication_Field = $factory->getBoolean('GoogleAuthentication', $defaults['GoogleAuthentication'], $GA_access);
        $container->addFormField(
            $GoogleAuthentication_Field,
            $factory->getLabel('GoogleAuthentication'),
            $pageIds[0]
            );

    }

    function handle(&$ServerScriptHelper, &$errors, &$cce_info, &$attributes) {

        $this->attributes = $attributes;

        if (!isset($this->attributes['Shell_enabled'])) {
            $this->attributes['Shell_enabled'] = "0";
        }

        if (!isset($this->attributes['GoogleAuthentication'])) {
            $this->attributes['GoogleAuthentication'] = "0";
        }

        $cce =& $ServerScriptHelper->getCceClient();

        $cce->set($cce_info["CCE_OID"], 'Shell', array('enabled' => $this->attributes['Shell_enabled']));

        $errors = array_merge($errors, $cce->errors());

        $cce->set($cce_info["CCE_OID"], 'SSH', array('GoogleAuthentication' => $this->attributes['GoogleAuthentication']));
        $errors = array_merge($errors, $cce->errors());

    }
}
?>
