<?php
// $Id: 60_Shell.php.defaults.Vsite
// Copyright (c) 2008-2023 Michael Stauber, SOLARSPEED.NET
// Copyright (c) 2008-2023 Team BlueOnyx, BLUEONYX.IT

include_once('UIExtension.php');

class ShellExtension extends UIExtension
{
    function display(&$ServerScriptHelper, &$container, $parameters)
    {
        $CI = get_instance();
        $System = $CI->getSystem();
        $factory = $ServerScriptHelper->getHtmlComponentFactory('base-shell');
        $cce = $ServerScriptHelper->getCceClient();
        
        $defaults = $cce->get($parameters['CCE_SERVICES_OID'], 'Shell');
    
        $shellEnable = $factory->getBoolean('enableShell', 
                            $defaults['enabled']);
        
        // assume PagedBlock because that is most likely going to be it
        $page_id = $parameters['PAGED_BLOCK_DEFAULT_PAGE'];

        $container->addFormField($shellEnable, $factory->getLabel("enableShell"), $page_id);

        // Sense checks:
        $System_SSH = $cce->get($System['OID'], 'SSH');
        if (($System_SSH['GoogleAuthentication'] == '0') && ($defaults['GoogleAuthentication'] == '1')) {
            // System has 'GoogleAuthentication' OFF, so Users of this Vsite cannot have it ON:
            $defaults['GoogleAuthentication'] = '0';
        }

        // Google Authenticator enabled or not:
        $GA_access = 'rw';
        if ($System_SSH['GoogleAuthentication'] == '0') {
            // 'GoogleAuthentication' is disabled in the server settings or Vsite settings:
            $defaults['GoogleAuthentication'] = '0';
            $GA_access = 'r';
        }
        $GoogleAuthentication_Field = $factory->getBoolean('GoogleAuthentication', $defaults['GoogleAuthentication'], $GA_access);
        $container->addFormField(
            $GoogleAuthentication_Field,
            $factory->getLabel('GoogleAuthentication'),
            $page_id
            );

    }

    function handle(&$ServerScriptHelper, &$errors, $parameters, &$attributes)
    {
        //global $Shell_enabled;
        $this->attributes = $attributes;

        $cce = $ServerScriptHelper->getCceClient();

        if (!isset($this->attributes['enableShell'])) {
            $this->attributes['enableShell'] = "0";
        }

        if (!isset($this->attributes['GoogleAuthentication'])) {
            $this->attributes['GoogleAuthentication'] = "0";
        }

        $cce->set($parameters["CCE_SERVICES_OID"], "Shell", array("enabled" => $this->attributes['enableShell'], 'GoogleAuthentication' => $this->attributes['GoogleAuthentication']));
        $errors = array_merge($errors, $cce->errors());
    }
}

?>
