<?php
// $Id: Shell.php.modify.User
// Copyright (c) 2008-2023 Michael Stauber, SOLARSPEED.NET
// Copyright (c) 2008-2023 Team BlueOnyx, BLUEONYX.IT
// Copyright (c) 2001 Sun Microsystems, Inc.
// All Rights Reserved.

include_once('UIExtension.php');

class ShellExtension extends UIExtension {
    function display(&$ServerScriptHelper, &$container, $parameters) {
        $factory = $ServerScriptHelper->getHtmlComponentFactory("base-shell");
        $cce = $ServerScriptHelper->getCceClient();

        $CI = get_instance();
        $System = $CI->getSystem();
        $i18n = new I18n("base-shell", $CI->BX_SESSION['loginUser']['localePreference']);

        $System_SSH = $cce->get($System['OID'], 'SSH');

        // if configuring for virtual sites, don't show if the feature
        // is not enabled 
        if ( isset($parameters["VSITE_OID"]) ) {
            $feature = $cce->get($parameters["VSITE_OID"], "Shell");
            if ( !$feature["enabled"] ) {
                return;
            }
        }   
        $UserData = $cce->get($parameters["CCE_OID"]);
        $User_Shell = $cce->get($parameters["CCE_OID"], "Shell");
        $User_SSH = $cce->get($parameters["CCE_OID"], "SSH");

        //
        //-- Sense Checks:
        //

        if ($System_SSH['GoogleAuthentication'] == '0') {
            // System has 'GoogleAuthentication' OFF, User cannot have it ON:
            $User_SSH['GoogleAuthentication'] = '0';
        }

        if (isset($feature['GoogleAuthentication'])) {
            if ($feature['GoogleAuthentication'] == '0') {
                // Vsite has 'GoogleAuthentication' OFF, User cannot have it ON:
                $User_SSH['GoogleAuthentication'] = '0';
            }
        }

        // Find out if user has the Google Authenticator config and QR image in his homedir:
        $is_there = '';
        $loginName = $UserData['name'];
        $dotgoogle_authenticator = '0';
        $ret = $CI->serverScriptHelper->shell("/usr/sausalito/sbin/gauth_check.sh $loginName" . $is_there, $output, 'root', $CI->BX_SESSION['sessionId']);
        if ($ret == 0) {
            // Google Authenticator Config present:
            $dotgoogle_authenticator = '1';
        }

        if (($User_SSH['GoogleAuthentication'] == '0') && ($dotgoogle_authenticator == '1')) {
            // User has 'GoogleAuthentication' disabled. 
            // User has dotgoogle_authenticator present
            // Fix it:
            $cce->set($parameters["CCE_OID"], 'SSH', array('GoogleAuthentication' => '1'));
            $cce->set($parameters["CCE_OID"], 'SSH', array('GoogleAuthentication' => '0'));
            $User_SSH['GoogleAuthentication'] = '0';
        }
        if (($User_SSH['GoogleAuthentication'] == '1') && ($dotgoogle_authenticator == '0')) {
            // User has 'GoogleAuthentication' enabled.
            // User has dotgoogle_authenticator absent
            // Fix it:
            $cce->set($parameters["CCE_OID"], 'SSH', array('GoogleAuthentication' => '0'));
            $cce->set($parameters["CCE_OID"], 'SSH', array('GoogleAuthentication' => '1'));
            $User_SSH['GoogleAuthentication'] = '1';
        }

        //
        //-- Page:
        //
    
        $shellEnable = $factory->getBoolean("Shell_enabled", $User_Shell["enabled"]);
        
        // assume PagedBlock because that is most likely going to be it
        $pageIds = $container->getPageIds();
        $container->addFormField(
                $shellEnable, 
                $factory->getLabel("userEnableShell"), $pageIds[0]);

        // Google Authenticator enabled or not:
        $GA_access = 'rw';
        if (($System_SSH['GoogleAuthentication'] == '0') || ($feature['GoogleAuthentication'] == '0')) {
            // 'GoogleAuthentication' is disabled in the server settings or Vsite settings:
            $User_SSH['GoogleAuthentication'] = '0';
            $GA_access = 'r';
        }
        $GoogleAuthentication_Field = $factory->getBoolean('GoogleAuthentication', $User_SSH['GoogleAuthentication'], $GA_access);
        $container->addFormField(
            $GoogleAuthentication_Field,
            $factory->getLabel('GoogleAuthentication'),
            $pageIds[0]
            );
    }

    function handle(&$ServerScriptHelper, &$errors, &$cce_info, &$attributes) {

        $this->attributes = $attributes;

        if (!isset($this->attributes['Shell_enabled'])) {
            $this->attributes['Shell_enabled'] = "0";
        }

        if (!isset($this->attributes['GoogleAuthentication'])) {
            $this->attributes['GoogleAuthentication'] = "0";
        }

        $cce =& $ServerScriptHelper->getCceClient();

        $cce->set($cce_info["CCE_OID"], 'Shell', array('enabled' => $this->attributes['Shell_enabled']));

        $errors = array_merge($errors, $cce->errors());

        $cce->set($cce_info["CCE_OID"], 'SSH', array('GoogleAuthentication' => $this->attributes['GoogleAuthentication']));
        $errors = array_merge($errors, $cce->errors());
    }
}
?>
